@@ -1,7 +1,12 @@
 echo "# $EXTENSION/build_order.txt" 				 	 > $EXTENSION/build_order.txt
 echo "# <scriptname> (without .sh)" 					>> $EXTENSION/build_order.txt
 echo "" 												>> $EXTENSION/build_order.txt
-if [ $BUILD_ALL == "false" ] && [ ! -d /usr/share/hwdata ]; then
+	
+RUN_INSTALL=false
+[[ ! $(pkg-config hwdata --exists && echo $?) ]] && RUN_INSTALL=true
+[[ $(pkg-config hwdata --exists && echo $?) == 0 ]] && [[ $(pkg-config hwdata --modversion) != "0.398" ]] && RUN_INSTALL=true
+
+if [[ $BUILD_ALL == "false" ]] && [[ $RUN_INSTALL == "true" ]]; then
 	echo "hwdata" 										>> $EXTENSION/build_order.txt
 fi
 if [ $BUILD_ALL == "true" ]; then
